@@ -38,17 +38,15 @@
 #ifndef DEALER_H
 #define DEALER_H
 
-class CardDiff;
 class DealerInfo;
 #include "gamestate.h"
 class MessageBox;
 class MoveHint;
 #include "patpile.h"
-class Solver;
+class SolverInterface;
 class SolverThread;
 #include "speeds.h"
 #include "view.h"
-#include "patsolve/patsolve.h"
 
 #include "KCardDeck"
 #include "KCardScene"
@@ -57,7 +55,6 @@ class QAction;
 #include <QMap>
 #include <QStack>
 #include <QTimer>
-class QDomDocument;
 
 
 class DealerScene : public KCardScene
@@ -104,7 +101,7 @@ public:
     bool isDemoActive() const;
 
     void setSolverEnabled( bool enabled );
-    Solver * solver() const;
+    SolverInterface * solver() const;
     void startSolver();
 
     virtual bool isGameLost() const;
@@ -167,7 +164,7 @@ protected:
 
     virtual void restart( const QList<KCard*> & cards ) = 0;
 
-    void setSolver( Solver * solver );
+    void setSolver( SolverInterface * solver );
 
     virtual QList<MoveHint> getHints();
 
@@ -230,7 +227,7 @@ private:
 
     const DealerInfo * const m_di;
 
-    Solver * m_solver;
+    SolverInterface * m_solver;
     SolverThread * m_solverThread;
     QList<MOVE> m_winningMoves;
 
