@@ -22,11 +22,11 @@ class Golf;
 #include "patsolve.h"
 
 
-class GolfSolver : public Solver
+class GolfSolver : public Solver<9>
 {
 public:
     explicit GolfSolver(const Golf *dealer);
-    int good_automove(int o, int r);
+
     int get_possible_moves(int *a, int *numout) Q_DECL_OVERRIDE;
     bool isWon() Q_DECL_OVERRIDE;
     void make_move(MOVE *m) Q_DECL_OVERRIDE;
